==> FlamingText-0.0.6.tar.gz: FlamingText-0.0.6/README.md <==
# FlamingText

## Common use
```python
from flamingText import FlamingText 
obj = FlamingText()
print(obj.process())
```

## Parametres

If you want to change some of these parametres, visit flamingtext.com and research how to change. I think, these all are easy to change from its view. If you want to make transparent background `backgroundResizeToLayers=on&backgroundRadio=1&backgroundColor=%23FFFFFF` . But remember, all effects do not accept the transparent background. To find out about it visit the flamingtext.com and do change settings.

```
_comBuyRedirect: false
script: comics-logo
text: Firdavs
symbol_tagname: popular
fontsize: 95
fontname: SF Slapstick Comic
fontname_tagname: cool
textBorder: 5
growSize: 0
antialias: on
hinting: on
justify: 2
letterSpacing: 0
lineSpacing: 0
textSlant: 0
textVerticalSlant: 0
textAngle: 0
textOutline: off
textOutline: false
textOutlineSize: 2
fillTextType: 0
fillTextColor: #F00C0C
fillTextPattern: Wood
fillTextPattern_tagname: standard
fillTextGradient: Full saturation spectrum CCW
fillTextGradient_tagname: standard
fillTextGradientDirection: 0
fillTextGradientReverse: off
fillTextGradientSmartFit: 0
outlineSize: 4
fillOutlineType: 0
fillOutlineColor: #000000
fillOutlinePattern: Wood
fillOutlinePattern_tagname: standard
fillOutlineGradient: Full saturation spectrum CCW
fillOutlineGradient_tagname: standard
fillOutlineGradientDirection: 0
fillOutlineGradientReverse: off
fillOutlineGradientSmartFit: 0
outline2Size: 5
fillOutline2Type: 0
fillOutline2Color: #FFFFFF
fillOutline2Pattern: Wood
fillOutline2Pattern_tagname: standard
fillOutline2Gradient: Full saturation spectrum CCW
fillOutline2Gradient_tagname: standard
fillOutline2GradientDirection: 0
fillOutline2GradientReverse: off
fillOutline2GradientSmartFit: 0
curveHighlight: on
curveHighlight: false
curveBrightness: 41
curveFactor: 2.35
curveOffsetX: 0
curveOffsetY: 5
shadowOnFirstOutline: off
shadowType: 1
shadowXOffset: 4
shadowYOffset: 4
shadowBlur: 8
shadowColor: #000000
shadowOpacity: 80
reflectOpacity: 50
reflectTiltX: 0
reflectPercent: 66
reflectScaleYPercent: 100
reflectXOffset: 0
reflectYOffset: 0
shadowGlowColor: #0000FF
shadowGlowSize: 2
shadowGlowFeather: 5
shadowNormalColor: #3C3C3C
shadowNormalFeather: 2
shadowNormalOpacity: 50
shadowNormalTiltX: 40
shadowNormalScaleYPercent: 65
shadowNormalXOffset: 0
shadowNormalYOffset: 0
shadowSelfXOffset: 10
shadowSelfYOffset: 10
shadowSelfBlur: 0
shadowSelfOpacity: 50
backgroundResizeToLayers: on
backgroundRadio: 1
backgroundColor: #FFFFFF
backgroundPattern: Wood
backgroundPattern_tagname: standard
backgroundGradient: Full saturation spectrum CCW
backgroundGradient_tagname: standard
backgroundStarburstColorAlt: #ED2400
backgroundStarburstColor1: #BD2409
backgroundStarburstNum: 25
backgroundStarburstRayPercentage: 50
backgroundStarburstUseColor2: on
backgroundStarburstUseColor2: false
backgroundStarburstColor2: #000000
backgroundStarburstOffsetAngle: 0
backgroundStarburstXOffset: 0
backgroundStarburstYOffset: 0
backgroundStarburstCenterPercentage: 2
backgroundStarburstRadiusX: 300
backgroundStarburstRadiusY: 300
backgroundUseOverlay: off
backgroundOverlayMode: 5
backgroundOverlayPattern: Parque #1
backgroundOverlayPattern_tagname: standard
backgroundOverlayOpacity: 100
backgroundImageUrl: http://www.flamingtext.com/images/textures/texture3.jpg
useFixedSize: off
useFixedSize: false
imageWidth: 400
imageHeight: 150
imageAlignment: 4
autocrop: off
autocrop: false
autocropPadding: 0
watermark: none
ext: png
jpgQuality: 85
doScale: off
scaleWidth: 240
scaleHeight: 120
```

==> FlamingText-0.0.7.tar.gz: FlamingText-0.0.7/README.md <==
# FlamingText

## Common use
```python
from flamingText import FlamingText 
obj = FlamingText(text="Firdavs-coder", script="fluffy-logo")
print(obj.process().text)
```

## How to get script or effect name ?
To select a certain effect, you have to visit https://flamingtext.com/ and find any kind of effect. For example, the first one on the list is https://flamingtext.com/logo/Design-Comics?_variations=true. Visit the link and copy the image, which is in the center of the page. If it has not been changed, there has to be a WROOM image. Then copy the image URL and, as you see in the URL script query. You can find other details and parameter information on the website by editing the image and analysing the url, as described above.

## Parametres

If you want to change some of these parametres, visit https://flamingtext.com/ and research how to change. I think, these all are easy to change from its view. If you want to make transparent background `backgroundResizeToLayers=on&backgroundRadio=1&backgroundColor=%23FFFFFF` . But remember, all effects do not accept the transparent background. To find out about it visit the https://flamingtext.com/ and do change settings.

```
_comBuyRedirect: false
script: comics-logo
text: Firdavs
symbol_tagname: popular
fontsize: 95
fontname: SF Slapstick Comic
fontname_tagname: cool
textBorder: 5
growSize: 0
antialias: on
hinting: on
justify: 2
letterSpacing: 0
lineSpacing: 0
textSlant: 0
textVerticalSlant: 0
textAngle: 0
textOutline: off
textOutline: false
textOutlineSize: 2
fillTextType: 0
fillTextColor: #F00C0C
fillTextPattern: Wood
fillTextPattern_tagname: standard
fillTextGradient: Full saturation spectrum CCW
fillTextGradient_tagname: standard
fillTextGradientDirection: 0
fillTextGradientReverse: off
fillTextGradientSmartFit: 0
outlineSize: 4
fillOutlineType: 0
fillOutlineColor: #000000
fillOutlinePattern: Wood
fillOutlinePattern_tagname: standard
fillOutlineGradient: Full saturation spectrum CCW
fillOutlineGradient_tagname: standard
fillOutlineGradientDirection: 0
fillOutlineGradientReverse: off
fillOutlineGradientSmartFit: 0
outline2Size: 5
fillOutline2Type: 0
fillOutline2Color: #FFFFFF
fillOutline2Pattern: Wood
fillOutline2Pattern_tagname: standard
fillOutline2Gradient: Full saturation spectrum CCW
fillOutline2Gradient_tagname: standard
fillOutline2GradientDirection: 0
fillOutline2GradientReverse: off
fillOutline2GradientSmartFit: 0
curveHighlight: on
curveHighlight: false
curveBrightness: 41
curveFactor: 2.35
curveOffsetX: 0
curveOffsetY: 5
shadowOnFirstOutline: off
shadowType: 1
shadowXOffset: 4
shadowYOffset: 4
shadowBlur: 8
shadowColor: #000000
shadowOpacity: 80
reflectOpacity: 50
reflectTiltX: 0
reflectPercent: 66
reflectScaleYPercent: 100
reflectXOffset: 0
reflectYOffset: 0
shadowGlowColor: #0000FF
shadowGlowSize: 2
shadowGlowFeather: 5
shadowNormalColor: #3C3C3C
shadowNormalFeather: 2
shadowNormalOpacity: 50
shadowNormalTiltX: 40
shadowNormalScaleYPercent: 65
shadowNormalXOffset: 0
shadowNormalYOffset: 0
shadowSelfXOffset: 10
shadowSelfYOffset: 10
shadowSelfBlur: 0
shadowSelfOpacity: 50
backgroundResizeToLayers: on
backgroundRadio: 1
backgroundColor: #FFFFFF
backgroundPattern: Wood
backgroundPattern_tagname: standard
backgroundGradient: Full saturation spectrum CCW
backgroundGradient_tagname: standard
backgroundStarburstColorAlt: #ED2400
backgroundStarburstColor1: #BD2409
backgroundStarburstNum: 25
backgroundStarburstRayPercentage: 50
backgroundStarburstUseColor2: on
backgroundStarburstUseColor2: false
backgroundStarburstColor2: #000000
backgroundStarburstOffsetAngle: 0
backgroundStarburstXOffset: 0
backgroundStarburstYOffset: 0
backgroundStarburstCenterPercentage: 2
backgroundStarburstRadiusX: 300
backgroundStarburstRadiusY: 300
backgroundUseOverlay: off
backgroundOverlayMode: 5
backgroundOverlayPattern: Parque #1
backgroundOverlayPattern_tagname: standard
backgroundOverlayOpacity: 100
backgroundImageUrl: http://www.flamingtext.com/images/textures/texture3.jpg
useFixedSize: off
useFixedSize: false
imageWidth: 400
imageHeight: 150
imageAlignment: 4
autocrop: off
autocrop: false
autocropPadding: 0
watermark: none
ext: png
jpgQuality: 85
doScale: off
scaleWidth: 240
scaleHeight: 120
```

<a href="https://www.buymeacoffee.com/firdavs" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee" style="height: 41px !important;width: 174px !important;box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;-webkit-box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;" ></a>
